@@ -162,6 +162,7 @@ main_start (gchar *url)
 	}
 	
 	main_open_new_window (yelp_base, url);
+	gdk_notify_startup_complete ();
 	
 	bonobo_object_release_unref (yelp_base, NULL);
 
@@ -316,8 +317,7 @@ main (int argc, char **argv)
 	textdomain(GETTEXT_PACKAGE);
 
 	program = gnome_program_init (PACKAGE, VERSION,
-				      LIBGNOMEUI_MODULE,
-				      argc, argv,
+				      LIBGNOMEUI_MODULE, argc, argv,
 				      GNOME_PARAM_POPT_TABLE, options,
 				      GNOME_PROGRAM_STANDARD_PROPERTIES,
 				      NULL);
