@@ -753,7 +753,7 @@ window_handle_pager_uri (YelpWindow  *window,
     if (yelp_uri_get_resource_type (uri) == YELP_URI_TYPE_TOC) {
 	pager = YELP_PAGER (yelp_toc_pager_get ());
     } else {
-	path  = g_strdup (gnome_vfs_uri_get_path (uri->uri));
+	path  = (gchar *) gnome_vfs_uri_get_path (uri->uri);
 	pager = (YelpPager *) yelp_cache_lookup (path);
 
 	// Create a new pager if one doesn't exist in the cache
@@ -773,7 +773,7 @@ window_handle_pager_uri (YelpWindow  *window,
 	    }
 
 	    if (pager)
-		yelp_cache_add (path, (GObject *) pager);
+		yelp_cache_add (g_strdup (path), (GObject *) pager);
 	}
     }
 
@@ -1034,6 +1034,8 @@ window_handle_page (YelpWindow   *window,
 		break;
 	    }
 
+	    g_free (id);
+
 	    valid = tree_model_iter_following (model, &iter);
 	}
     }
@@ -1133,7 +1135,8 @@ yelp_window_destroyed (GtkWidget *window,
     g_object_unref (priv->pane);
     g_object_unref (priv->side_sw);
     g_object_unref (priv->html_sw);
-    g_object_unref (priv->pager);
+    if (priv->pager)
+	g_object_unref (priv->pager);
 }
 
 static void
